@@ -1,4 +1,5 @@
 #include <librapid/array/extent.hpp>
+#include <librapid/array/esiterator.hpp>
 #include <sstream>
 
 namespace librapid {
@@ -7,14 +8,12 @@ namespace librapid {
 		m_dims = data.size();
 
 		if (m_dims > LIBRAPID_MAX_DIMS)
-			throw std::runtime_error("Cannot create Extent with "
-									 + std::to_string(m_dims)
-									 + " dimensions. Limit is "
-									 + std::to_string(LIBRAPID_MAX_DIMS));
+			throw std::runtime_error(
+			  "Cannot create Extent with " + std::to_string(m_dims) +
+			  " dimensions. Limit is " + std::to_string(LIBRAPID_MAX_DIMS));
 
 		uint64_t index = 0;
-		for (const auto &val: data)
-			m_extent[index++] = val;
+		for (const auto &val : data) m_extent[index++] = val;
 
 		update();
 	}
@@ -24,13 +23,11 @@ namespace librapid {
 		m_dims = data.size();
 
 		if (m_dims > LIBRAPID_MAX_DIMS)
-			throw std::runtime_error("Cannot create Extent with "
-									 + std::to_string(m_dims)
-									 + " dimensions. Limit is "
-									 + std::to_string(LIBRAPID_MAX_DIMS));
+			throw std::runtime_error(
+			  "Cannot create Extent with " + std::to_string(m_dims) +
+			  " dimensions. Limit is " + std::to_string(LIBRAPID_MAX_DIMS));
 
-		for (uint64_t i = 0; i < data.size(); i++)
-			m_extent[i] = data[i];
+		for (uint64_t i = 0; i < data.size(); i++) m_extent[i] = data[i];
 
 		update();
 	}
@@ -40,10 +37,9 @@ namespace librapid {
 		m_dims = other.m_dims;
 
 		if (m_dims > LIBRAPID_MAX_DIMS)
-			throw std::runtime_error("Cannot create Extent with "
-									 + std::to_string(m_dims)
-									 + " dimensions. Limit is "
-									 + std::to_string(LIBRAPID_MAX_DIMS));
+			throw std::runtime_error(
+			  "Cannot create Extent with " + std::to_string(m_dims) +
+			  " dimensions. Limit is " + std::to_string(LIBRAPID_MAX_DIMS));
 
 		for (int64_t i = 0; i < other.m_dims; i++)
 			m_extent[i] = other.m_extent[i];
@@ -55,25 +51,21 @@ namespace librapid {
 		m_dims = dims;
 		m_size = dims;
 		if (m_dims > LIBRAPID_MAX_DIMS)
-			throw std::runtime_error("Cannot create Extent with "
-									 + std::to_string(m_dims)
-									 + " dimensions. Limit is "
-									 + std::to_string(LIBRAPID_MAX_DIMS));
+			throw std::runtime_error(
+			  "Cannot create Extent with " + std::to_string(m_dims) +
+			  " dimensions. Limit is " + std::to_string(LIBRAPID_MAX_DIMS));
 
-		for (int64_t i = 0; i < m_dims; ++i)
-			m_extent[i] = 1;
+		for (int64_t i = 0; i < m_dims; ++i) m_extent[i] = 1;
 	}
 
 #ifdef LIBRAPID_PYTHON
-	Extent::Extent(py::args args)
-	{
+	Extent::Extent(py::args args) {
 		m_dims = py::len(args);
 
 		if (m_dims > LIBRAPID_MAX_DIMS)
-			throw std::runtime_error("Cannot create Extent with "
-									 + std::to_string(m_dims)
-									 + " dimensions. Limit is "
-									 + std::to_string(LIBRAPID_MAX_DIMS));
+			throw std::runtime_error(
+			  "Cannot create Extent with " + std::to_string(m_dims) +
+			  " dimensions. Limit is " + std::to_string(LIBRAPID_MAX_DIMS));
 
 		for (int64_t i = 0; i < m_dims; i++)
 			m_extent[i] = py::cast<int64_t>(args[i]);
@@ -84,8 +76,8 @@ namespace librapid {
 
 	Extent &Extent::operator=(const Extent &other) {
 		memcpy(m_extent, other.m_extent, sizeof(int64_t) * LIBRAPID_MAX_DIMS);
-		m_dims = other.m_dims;
-		m_size = other.m_size;
+		m_dims				= other.m_dims;
+		m_size				= other.m_size;
 		m_containsAutomatic = other.m_containsAutomatic;
 
 		update();
@@ -95,21 +87,20 @@ namespace librapid {
 
 	const int64_t &Extent::operator[](int64_t index) const {
 		if (index >= m_dims)
-			throw std::out_of_range("Index " + std::to_string(index)
-									+ " is out of range for Extent with "
-									+ std::to_string(m_dims) + " dimensions");
+			throw std::out_of_range("Index " + std::to_string(index) +
+									" is out of range for Extent with " +
+									std::to_string(m_dims) + " dimensions");
 
 		return m_extent[index];
 	}
 
 	int64_t &Extent::operator[](int64_t index) {
 		if (index >= m_dims)
-			throw std::out_of_range("Index " + std::to_string(index)
-									+ " is out of range for Extent with "
-									+ std::to_string(m_dims) + " dimensions");
+			throw std::out_of_range("Index " + std::to_string(index) +
+									" is out of range for Extent with " +
+									std::to_string(m_dims) + " dimensions");
 
-		if (m_isDirty)
-			update();
+		if (m_isDirty) update();
 
 		m_isDirty = true;
 
@@ -122,17 +113,16 @@ namespace librapid {
 			if (m_extent[i] < 0) ++neg;
 
 		if (neg > 1)
-			throw std::invalid_argument("Cannot construct Extent with more than"
-										" one automatic values. " +
-										std::to_string(neg) +
-										" automatic values were found.");
+			throw std::invalid_argument(
+			  "Cannot construct Extent with more than"
+			  " one automatic values. " +
+			  std::to_string(neg) + " automatic values were found.");
 
 		// If no automatic dimensions exist, quick return
-		if (!m_isDirty && !m_containsAutomatic)
-			return *this;
+		if (!m_isDirty && !m_containsAutomatic) return *this;
 
 		int64_t autoIndex = 0;
-		int64_t prod = 1;
+		int64_t prod	  = 1;
 
 		for (int64_t i = 0; i < m_dims; ++i) {
 			if (m_extent[i] < 1)
@@ -142,14 +132,15 @@ namespace librapid {
 		}
 
 		if (target % prod == 0) {
-			Extent res = *this;
+			Extent res				= *this;
 			res.m_extent[autoIndex] = target / prod;
 			return res;
 		}
 
-		throw std::runtime_error("Could not resolve automatic dimension of "
-								 " Extent to fit " + std::to_string(target)
-								 + " elements");
+		throw std::runtime_error(
+		  "Could not resolve automatic dimension of "
+		  " Extent to fit " +
+		  std::to_string(target) + " elements");
 	}
 
 	Extent Extent::subExtent(int64_t start, int64_t end) const {
@@ -157,9 +148,9 @@ namespace librapid {
 		if (end == -1) end = m_dims;
 
 		if (start >= end)
-			throw std::invalid_argument("Cannot create subExtent from range ["
-										+ std::to_string(start) + ", "
-										+ std::to_string(end) + ")");
+			throw std::invalid_argument("Cannot create subExtent from range [" +
+										std::to_string(start) + ", " +
+										std::to_string(end) + ")");
 
 		Extent res(end - start);
 		for (int64_t i = start; i < end; ++i)
@@ -169,15 +160,12 @@ namespace librapid {
 	}
 
 	bool Extent::operator==(const Extent &other) const {
-		if (m_dims != other.m_dims)
-			return false;
+		if (m_dims != other.m_dims) return false;
 
-		if (m_containsAutomatic != other.m_containsAutomatic)
-			return false;
+		if (m_containsAutomatic != other.m_containsAutomatic) return false;
 
 		for (int64_t i = 0; i < m_dims; ++i) {
-			if (m_extent[i] != other.m_extent[i])
-				return false;
+			if (m_extent[i] != other.m_extent[i]) return false;
 		}
 
 		return true;
@@ -199,8 +187,7 @@ namespace librapid {
 			else
 				res << m_extent[i];
 
-			if (i < m_dims - 1)
-				res << ", ";
+			if (i < m_dims - 1) res << ", ";
 		}
 		res << ")";
 
@@ -209,7 +196,7 @@ namespace librapid {
 
 	void Extent::update() {
 		int64_t neg = 0;
-		m_size = 1;
+		m_size		= 1;
 		for (int64_t i = 0; i < m_dims; i++) {
 			m_size *= m_extent[i];
 
@@ -222,13 +209,13 @@ namespace librapid {
 		if (neg == 1)
 			m_containsAutomatic = true;
 		else if (neg > 1)
-			throw std::invalid_argument("Cannot construct Extent with more than"
-										" one automatic values. " +
-										std::to_string(neg) +
-										" automatic values were found.");
+			throw std::invalid_argument(
+			  "Cannot construct Extent with more than"
+			  " one automatic values. " +
+			  std::to_string(neg) + " automatic values were found.");
 		else
 			m_containsAutomatic = false;
 
 		m_isDirty = false;
 	}
-}
\ No newline at end of file
+} // namespace librapid
\ No newline at end of file
