@@ -3,6 +3,20 @@
 #include <librapid/utils/array_utils.hpp>
 
 namespace librapid {
+	// ========= Negation =========
+
+	void negate(const Array &a, Array &res) {
+		Array::applyUnaryOp(res, a, ops::Negate());
+	}
+
+	Array negate(const Array &a) {
+		return Array::applyUnaryOp(a, ops::Negate());
+	}
+
+	Array Array::operator-() const {
+		return Array::applyUnaryOp(*this, ops::Negate());
+	}
+
 	// ========= Addition =========
 
 	void add(const Array &a, const Array &b, Array &res) {
@@ -58,4 +72,4 @@ namespace librapid {
 	Array Array::operator/(const Array &other) const {
 		return div(*this, other);
 	}
-}
\ No newline at end of file
+} // namespace librapid
\ No newline at end of file
