@@ -3,10 +3,11 @@
 
 namespace librapid {
 	Array Array::clone(Datatype dtype, Accelerator locn) const {
-		Array res(m_extent, dtype == Datatype::NONE ? m_dtype : dtype,
+		Array res(m_extent,
+				  dtype == Datatype::NONE ? m_dtype : dtype,
 				  locn == Accelerator::NONE ? m_location : locn);
 		res.m_isScalar = m_isScalar;
-		res.m_isChild = false;
+		res.m_isChild  = false;
 		applyUnaryOp(res, *this, ops::Copy());
 		return res;
 	}
@@ -19,7 +20,8 @@ namespace librapid {
 		return clone(dtype, stringToAccelerator(locn));
 	}
 
-	Array Array::clone(const std::string &dtype, const std::string &locn) const {
+	Array Array::clone(const std::string &dtype,
+					   const std::string &locn) const {
 		return clone(stringToDatatype(dtype), stringToAccelerator(locn));
 	}
-}
\ No newline at end of file
+} // namespace librapid
\ No newline at end of file
