@@ -28,6 +28,7 @@
 #ifndef HELPER_CUSOLVER
 #define HELPER_CUSOLVER
 
+#include "cusparse.h"
 #include <ctype.h>
 #include <cuda_runtime.h>
 #include <math.h>
@@ -35,22 +36,20 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "cusparse.h"
-
 #define SWITCH_CHAR '-'
 
 struct testOpts {
-	char *sparse_mat_filename;  // by switch -F<filename>
-	const char *testFunc;       // by switch -R<name>
-	const char *reorder;        // by switch -P<name>
-	int lda;                    // by switch -lda<int>
+	char *sparse_mat_filename; // by switch -F<filename>
+	const char *testFunc;	   // by switch -R<name>
+	const char *reorder;	   // by switch -P<name>
+	int lda;				   // by switch -lda<int>
 };
 
 double vec_norminf(int n, const double *x) {
 	double norminf = 0;
 	for (int j = 0; j < n; j++) {
 		double x_abs = fabs(x[j]);
-		norminf = (norminf > x_abs) ? norminf : x_abs;
+		norminf		 = (norminf > x_abs) ? norminf : x_abs;
 	}
 	return norminf;
 }
@@ -78,13 +77,13 @@ double csr_mat_norminf(int m, int n, int nnzA, const cusparseMatDescr_t descrA,
 					   const double *csrValA, const int *csrRowPtrA,
 					   const int *csrColIndA) {
 	const int baseA =
-			(CUSPARSE_INDEX_BASE_ONE == cusparseGetMatIndexBase(descrA)) ? 1 : 0;
+	  (CUSPARSE_INDEX_BASE_ONE == cusparseGetMatIndexBase(descrA)) ? 1 : 0;
 
 	double norminf = 0;
 	for (int i = 0; i < m; i++) {
-		double sum = 0.0;
+		double sum		= 0.0;
 		const int start = csrRowPtrA[i] - baseA;
-		const int end = csrRowPtrA[i + 1] - baseA;
+		const int end	= csrRowPtrA[i + 1] - baseA;
 		for (int colidx = start; colidx < end; colidx++) {
 			// const int j = csrColIndA[colidx] - baseA;
 			double A_abs = fabs(csrValA[colidx]);
@@ -99,27 +98,27 @@ void display_matrix(int m, int n, int nnzA, const cusparseMatDescr_t descrA,
 					const double *csrValA, const int *csrRowPtrA,
 					const int *csrColIndA) {
 	const int baseA =
-			(CUSPARSE_INDEX_BASE_ONE == cusparseGetMatIndexBase(descrA)) ? 1 : 0;
+	  (CUSPARSE_INDEX_BASE_ONE == cusparseGetMatIndexBase(descrA)) ? 1 : 0;
 
 	printf("m = %d, n = %d, nnz = %d, matlab base-1\n", m, n, nnzA);
 
 	for (int row = 0; row < m; row++) {
 		const int start = csrRowPtrA[row] - baseA;
-		const int end = csrRowPtrA[row + 1] - baseA;
+		const int end	= csrRowPtrA[row + 1] - baseA;
 		for (int colidx = start; colidx < end; colidx++) {
 			const int col = csrColIndA[colidx] - baseA;
-			double Areg = csrValA[colidx];
+			double Areg	  = csrValA[colidx];
 			printf("A(%d, %d) = %20.16E\n", row + 1, col + 1, Areg);
 		}
 	}
 }
 
 #if defined(_WIN32)
-#if !defined(WIN32_LEAN_AND_MEAN)
-#define WIN32_LEAN_AND_MEAN
-#endif
+#	if !defined(WIN32_LEAN_AND_MEAN)
+#		define WIN32_LEAN_AND_MEAN
+#	endif
 
-#include <windows.h>
+#	include <windows.h>
 
 double second(void) {
 	LARGE_INTEGER t;
@@ -128,41 +127,41 @@ double second(void) {
 	static BOOL hasHighResTimer;
 
 	if (!checkedForHighResTimer) {
-		hasHighResTimer = QueryPerformanceFrequency(&t);
-		oofreq = 1.0 / (double) t.QuadPart;
+		hasHighResTimer		   = QueryPerformanceFrequency(&t);
+		oofreq				   = 1.0 / (double)t.QuadPart;
 		checkedForHighResTimer = 1;
 	}
 	if (hasHighResTimer) {
 		QueryPerformanceCounter(&t);
-		return (double) t.QuadPart * oofreq;
+		return (double)t.QuadPart * oofreq;
 	} else {
-		return (double) GetTickCount() / 1000.0;
+		return (double)GetTickCount() / 1000.0;
 	}
 }
 
 #elif defined(__linux__) || defined(__QNX__)
-#include <stddef.h>
-#include <sys/resource.h>
-#include <sys/time.h>
+#	include <stddef.h>
+#	include <sys/resource.h>
+#	include <sys/time.h>
 double second(void) {
-  struct timeval tv;
-  gettimeofday(&tv, NULL);
-  return (double)tv.tv_sec + (double)tv.tv_usec / 1000000.0;
+	struct timeval tv;
+	gettimeofday(&tv, NULL);
+	return (double)tv.tv_sec + (double)tv.tv_usec / 1000000.0;
 }
 
 #elif defined(__APPLE__)
-#include <stddef.h>
-#include <sys/resource.h>
-#include <sys/sysctl.h>
-#include <sys/time.h>
-#include <sys/types.h>
+#	include <stddef.h>
+#	include <sys/resource.h>
+#	include <sys/sysctl.h>
+#	include <sys/time.h>
+#	include <sys/types.h>
 double second(void) {
-  struct timeval tv;
-  gettimeofday(&tv, NULL);
-  return (double)tv.tv_sec + (double)tv.tv_usec / 1000000.0;
+	struct timeval tv;
+	gettimeofday(&tv, NULL);
+	return (double)tv.tv_sec + (double)tv.tv_usec / 1000000.0;
 }
 #else
-#error unsupported platform
+#	error unsupported platform
 #endif
 
 #endif
