@@ -29,42 +29,41 @@
 #ifndef COMMON_HELPER_IMAGE_H_
 #define COMMON_HELPER_IMAGE_H_
 
+#include <algorithm>
 #include <assert.h>
 #include <exception.h>
-#include <math.h>
-#include <stdint.h>
-
-#include <algorithm>
 #include <fstream>
 #include <iostream>
+#include <math.h>
+#include <stdint.h>
 #include <string>
 #include <vector>
 
 #ifndef MIN
-#define MIN(a, b) ((a < b) ? a : b)
+#	define MIN(a, b) ((a < b) ? a : b)
 #endif
 #ifndef MAX
-#define MAX(a, b) ((a > b) ? a : b)
+#	define MAX(a, b) ((a > b) ? a : b)
 #endif
 
 #ifndef EXIT_WAIVED
-#define EXIT_WAIVED 2
+#	define EXIT_WAIVED 2
 #endif
 
 #include <helper_string.h>
 
 // namespace unnamed (internal)
 namespace helper_image_internal {
-//! size of PGM file header
+	//! size of PGM file header
 	const unsigned int PGMHeaderSize = 0x40;
 
-// types
+	// types
 
-//! Data converter from unsigned char / unsigned byte to type T
+	//! Data converter from unsigned char / unsigned byte to type T
 	template<class T>
 	struct ConverterFromUByte;
 
-//! Data converter from unsigned char / unsigned byte
+	//! Data converter from unsigned char / unsigned byte
 	template<>
 	struct ConverterFromUByte<unsigned char> {
 		//! Conversion operator
@@ -75,7 +74,7 @@ namespace helper_image_internal {
 		}
 	};
 
-//! Data converter from unsigned char / unsigned byte to float
+	//! Data converter from unsigned char / unsigned byte to float
 	template<>
 	struct ConverterFromUByte<float> {
 		//! Conversion operator
@@ -86,11 +85,11 @@ namespace helper_image_internal {
 		}
 	};
 
-//! Data converter from unsigned char / unsigned byte to type T
+	//! Data converter from unsigned char / unsigned byte to type T
 	template<class T>
 	struct ConverterToUByte;
 
-//! Data converter from unsigned char / unsigned byte to unsigned int
+	//! Data converter from unsigned char / unsigned byte to unsigned int
 	template<>
 	struct ConverterToUByte<unsigned char> {
 		//! Conversion operator (essentially a passthru
@@ -99,7 +98,7 @@ namespace helper_image_internal {
 		unsigned char operator()(const unsigned char &val) { return val; }
 	};
 
-//! Data converter from unsigned char / unsigned byte to unsigned int
+	//! Data converter from unsigned char / unsigned byte to unsigned int
 	template<>
 	struct ConverterToUByte<float> {
 		//! Conversion operator
@@ -109,28 +108,28 @@ namespace helper_image_internal {
 			return static_cast<unsigned char>(val * 255.0f);
 		}
 	};
-}  // namespace helper_image_internal
+} // namespace helper_image_internal
 
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
-#ifndef FOPEN
-#define FOPEN(fHandle, filename, mode) fopen_s(&fHandle, filename, mode)
-#endif
-#ifndef FOPEN_FAIL
-#define FOPEN_FAIL(result) (result != 0)
-#endif
-#ifndef SSCANF
-#define SSCANF sscanf_s
-#endif
+#	ifndef FOPEN
+#		define FOPEN(fHandle, filename, mode) fopen_s(&fHandle, filename, mode)
+#	endif
+#	ifndef FOPEN_FAIL
+#		define FOPEN_FAIL(result) (result != 0)
+#	endif
+#	ifndef SSCANF
+#		define SSCANF sscanf_s
+#	endif
 #else
-#ifndef FOPEN
-#define FOPEN(fHandle, filename, mode) (fHandle = fopen(filename, mode))
-#endif
-#ifndef FOPEN_FAIL
-#define FOPEN_FAIL(result) (result == NULL)
-#endif
-#ifndef SSCANF
-#define SSCANF sscanf
-#endif
+#	ifndef FOPEN
+#		define FOPEN(fHandle, filename, mode) (fHandle = fopen(filename, mode))
+#	endif
+#	ifndef FOPEN_FAIL
+#		define FOPEN_FAIL(result) (result == NULL)
+#	endif
+#	ifndef SSCANF
+#		define SSCANF sscanf
+#	endif
 #endif
 
 inline bool __loadPPM(const char *file, unsigned char **data, unsigned int *w,
@@ -146,7 +145,8 @@ inline bool __loadPPM(const char *file, unsigned char **data, unsigned int *w,
 	char header[helper_image_internal::PGMHeaderSize];
 
 	if (fgets(header, helper_image_internal::PGMHeaderSize, fp) == NULL) {
-		std::cerr << "__LoadPPM() : reading PGM header returned NULL" << std::endl;
+		std::cerr << "__LoadPPM() : reading PGM header returned NULL"
+				  << std::endl;
 		return false;
 	}
 
@@ -155,16 +155,17 @@ inline bool __loadPPM(const char *file, unsigned char **data, unsigned int *w,
 	} else if (strncmp(header, "P6", 2) == 0) {
 		*channels = 3;
 	} else {
-		std::cerr << "__LoadPPM() : File is not a PPM or PGM image" << std::endl;
+		std::cerr << "__LoadPPM() : File is not a PPM or PGM image"
+				  << std::endl;
 		*channels = 0;
 		return false;
 	}
 
 	// parse header, read maxval, width and height
-	unsigned int width = 0;
+	unsigned int width	= 0;
 	unsigned int height = 0;
 	unsigned int maxval = 0;
-	unsigned int i = 0;
+	unsigned int i		= 0;
 
 	while (i < 3) {
 		if (fgets(header, helper_image_internal::PGMHeaderSize, fp) == NULL) {
@@ -173,9 +174,7 @@ inline bool __loadPPM(const char *file, unsigned char **data, unsigned int *w,
 			return false;
 		}
 
-		if (header[0] == '#') {
-			continue;
-		}
+		if (header[0] == '#') { continue; }
 
 		if (i == 0) {
 			i += SSCANF(header, "%u %u %u", &width, &height, &maxval);
@@ -192,10 +191,10 @@ inline bool __loadPPM(const char *file, unsigned char **data, unsigned int *w,
 			std::cerr << "__LoadPPM() : Invalid image dimensions." << std::endl;
 		}
 	} else {
-		*data = (unsigned char *) malloc(sizeof(unsigned char) * width * height *
-										 *channels);
-		*w = width;
-		*h = height;
+		*data = (unsigned char *)malloc(sizeof(unsigned char) * width * height *
+										*channels);
+		*w	  = width;
+		*h	  = height;
 	}
 
 	// read and close file
@@ -215,9 +214,7 @@ inline bool sdkLoadPGM(const char *file, T **data, unsigned int *w,
 	unsigned char *idata = NULL;
 	unsigned int channels;
 
-	if (true != __loadPPM(file, &idata, w, h, &channels)) {
-		return false;
-	}
+	if (true != __loadPPM(file, &idata, w, h, &channels)) { return false; }
 
 	unsigned int size = *w * *h * channels;
 
@@ -228,7 +225,9 @@ inline bool sdkLoadPGM(const char *file, T **data, unsigned int *w,
 	}
 
 	// copy and cast data
-	std::transform(idata, idata + size, *data,
+	std::transform(idata,
+				   idata + size,
+				   *data,
 				   helper_image_internal::ConverterFromUByte<T>());
 
 	free(idata);
@@ -309,10 +308,11 @@ template<class T>
 inline bool sdkSavePGM(const char *file, T *data, unsigned int w,
 					   unsigned int h) {
 	unsigned int size = w * h;
-	unsigned char *idata = (unsigned char *) malloc(sizeof(unsigned char) * size);
+	unsigned char *idata =
+	  (unsigned char *)malloc(sizeof(unsigned char) * size);
 
-	std::transform(data, data + size, idata,
-				   helper_image_internal::ConverterToUByte<T>());
+	std::transform(
+	  data, data + size, idata, helper_image_internal::ConverterToUByte<T>());
 
 	// write file
 	bool result = __savePPM(file, idata, w, h, 1);
@@ -328,7 +328,7 @@ inline bool sdkSavePPM4ub(const char *file, unsigned char *data, unsigned int w,
 	// strip 4th component
 	int size = w * h;
 	unsigned char *ndata =
-			(unsigned char *) malloc(sizeof(unsigned char) * size * 3);
+	  (unsigned char *)malloc(sizeof(unsigned char) * size * 3);
 	unsigned char *ptr = ndata;
 
 	for (int i = 0; i < size; i++) {
@@ -387,8 +387,9 @@ inline bool sdkReadFile(const char *filename, T **data, unsigned int *len,
 		if (*len != data_read.size()) {
 			std::cerr << "sdkReadFile() : Initialized memory given but "
 					  << "size  mismatch with signal read "
-					  << "(data read / data init = " << (unsigned int) data_read.size()
-					  << " / " << *len << ")" << std::endl;
+					  << "(data read / data init = "
+					  << (unsigned int)data_read.size() << " / " << *len << ")"
+					  << std::endl;
 
 			return false;
 		}
@@ -520,11 +521,12 @@ inline bool compareData(const T *reference, const T *data,
 						const float threshold) {
 	assert(epsilon >= 0);
 
-	bool result = true;
+	bool result				 = true;
 	unsigned int error_count = 0;
 
 	for (unsigned int i = 0; i < len; ++i) {
-		float diff = static_cast<float>(reference[i]) - static_cast<float>(data[i]);
+		float diff =
+		  static_cast<float>(reference[i]) - static_cast<float>(data[i]);
 		bool comp = (diff <= epsilon) && (diff >= -epsilon);
 		result &= comp;
 
@@ -547,7 +549,8 @@ inline bool compareData(const T *reference, const T *data,
 	} else {
 		if (error_count) {
 			printf("%4.2f(%%) of bytes mismatched (count=%d)\n",
-				   static_cast<float>(error_count) * 100 / static_cast<float>(len),
+				   static_cast<float>(error_count) * 100 /
+					 static_cast<float>(len),
 				   error_count);
 		}
 
@@ -556,7 +559,7 @@ inline bool compareData(const T *reference, const T *data,
 }
 
 #ifndef __MIN_EPSILON_ERROR
-#define __MIN_EPSILON_ERROR 1e-3f
+#	define __MIN_EPSILON_ERROR 1e-3f
 #endif
 
 //////////////////////////////////////////////////////////////////////////////
@@ -575,31 +578,28 @@ inline bool compareDataAsFloatThreshold(const T *reference, const T *data,
 	assert(epsilon >= 0);
 
 	// If we set epsilon to be 0, let's set a minimum threshold
-	float max_error = MAX((float) epsilon, __MIN_EPSILON_ERROR);
+	float max_error = MAX((float)epsilon, __MIN_EPSILON_ERROR);
 	int error_count = 0;
-	bool result = true;
+	bool result		= true;
 
 	for (unsigned int i = 0; i < len; ++i) {
 		float diff =
-				fabs(static_cast<float>(reference[i]) - static_cast<float>(data[i]));
+		  fabs(static_cast<float>(reference[i]) - static_cast<float>(data[i]));
 		bool comp = (diff < max_error);
 		result &= comp;
 
-		if (!comp) {
-			error_count++;
-		}
+		if (!comp) { error_count++; }
 	}
 
 	if (threshold == 0.0f) {
-		if (error_count) {
-			printf("total # of errors = %d\n", error_count);
-		}
+		if (error_count) { printf("total # of errors = %d\n", error_count); }
 
 		return (error_count == 0) ? true : false;
 	} else {
 		if (error_count) {
 			printf("%4.2f(%%) of bytes mismatched (count=%d)\n",
-				   static_cast<float>(error_count) * 100 / static_cast<float>(len),
+				   static_cast<float>(error_count) * 100 /
+					 static_cast<float>(len),
 				   error_count);
 		}
 
@@ -623,7 +623,7 @@ inline bool sdkCompareBin2BinUint(const char *src_file, const char *ref_file,
 	FILE *src_fp = NULL, *ref_fp = NULL;
 
 	uint64_t error_count = 0;
-	size_t fsize = 0;
+	size_t fsize		 = 0;
 
 	if (FOPEN_FAIL(FOPEN(src_fp, src_file, "rb"))) {
 		printf("compareBin2Bin <unsigned int> unable to open src_file: %s\n",
@@ -635,47 +635,50 @@ inline bool sdkCompareBin2BinUint(const char *src_file, const char *ref_file,
 
 	if (ref_file_path == NULL) {
 		printf("compareBin2Bin <unsigned int>  unable to find <%s> in <%s>\n",
-			   ref_file, exec_path);
+			   ref_file,
+			   exec_path);
 		printf(">>> Check info.xml and [project//data] folder <%s> <<<\n",
 			   ref_file);
 		printf("Aborting comparison!\n");
 		printf("  FAILED\n");
 		error_count++;
 
-		if (src_fp) {
-			fclose(src_fp);
-		}
+		if (src_fp) { fclose(src_fp); }
 
-		if (ref_fp) {
-			fclose(ref_fp);
-		}
+		if (ref_fp) { fclose(ref_fp); }
 	} else {
 		if (FOPEN_FAIL(FOPEN(ref_fp, ref_file_path, "rb"))) {
 			printf(
-					"compareBin2Bin <unsigned int>"
-					" unable to open ref_file: %s\n",
-					ref_file_path);
+			  "compareBin2Bin <unsigned int>"
+			  " unable to open ref_file: %s\n",
+			  ref_file_path);
 			error_count++;
 		}
 
 		if (src_fp && ref_fp) {
-			src_buffer = (unsigned int *) malloc(nelements * sizeof(unsigned int));
-			ref_buffer = (unsigned int *) malloc(nelements * sizeof(unsigned int));
+			src_buffer =
+			  (unsigned int *)malloc(nelements * sizeof(unsigned int));
+			ref_buffer =
+			  (unsigned int *)malloc(nelements * sizeof(unsigned int));
 
 			fsize = fread(src_buffer, nelements, sizeof(unsigned int), src_fp);
 			fsize = fread(ref_buffer, nelements, sizeof(unsigned int), ref_fp);
 
 			printf(
-					"> compareBin2Bin <unsigned int> nelements=%d,"
-					" epsilon=%4.2f, threshold=%4.2f\n",
-					nelements, epsilon, threshold);
-			printf("   src_file <%s>, size=%d bytes\n", src_file,
+			  "> compareBin2Bin <unsigned int> nelements=%d,"
+			  " epsilon=%4.2f, threshold=%4.2f\n",
+			  nelements,
+			  epsilon,
+			  threshold);
+			printf("   src_file <%s>, size=%d bytes\n",
+				   src_file,
 				   static_cast<int>(fsize));
-			printf("   ref_file <%s>, size=%d bytes\n", ref_file_path,
+			printf("   ref_file <%s>, size=%d bytes\n",
+				   ref_file_path,
 				   static_cast<int>(fsize));
 
-			if (!compareData<unsigned int, float>(ref_buffer, src_buffer, nelements,
-												  epsilon, threshold)) {
+			if (!compareData<unsigned int, float>(
+				  ref_buffer, src_buffer, nelements, epsilon, threshold)) {
 				error_count++;
 			}
 
@@ -685,23 +688,19 @@ inline bool sdkCompareBin2BinUint(const char *src_file, const char *ref_file,
 			free(src_buffer);
 			free(ref_buffer);
 		} else {
-			if (src_fp) {
-				fclose(src_fp);
-			}
+			if (src_fp) { fclose(src_fp); }
 
-			if (ref_fp) {
-				fclose(ref_fp);
-			}
+			if (ref_fp) { fclose(ref_fp); }
 		}
 	}
 
 	if (error_count == 0) {
 		printf("  OK\n");
 	} else {
-		printf("  FAILURE: %d errors...\n", (unsigned int) error_count);
+		printf("  FAILURE: %d errors...\n", (unsigned int)error_count);
 	}
 
-	return (error_count == 0);  // returns true if all pixels pass
+	return (error_count == 0); // returns true if all pixels pass
 }
 
 inline bool sdkCompareBin2BinFloat(const char *src_file, const char *ref_file,
@@ -714,14 +713,16 @@ inline bool sdkCompareBin2BinFloat(const char *src_file, const char *ref_file,
 	uint64_t error_count = 0;
 
 	if (FOPEN_FAIL(FOPEN(src_fp, src_file, "rb"))) {
-		printf("compareBin2Bin <float> unable to open src_file: %s\n", src_file);
+		printf("compareBin2Bin <float> unable to open src_file: %s\n",
+			   src_file);
 		error_count = 1;
 	}
 
 	char *ref_file_path = sdkFindFilePath(ref_file, exec_path);
 
 	if (ref_file_path == NULL) {
-		printf("compareBin2Bin <float> unable to find <%s> in <%s>\n", ref_file,
+		printf("compareBin2Bin <float> unable to find <%s> in <%s>\n",
+			   ref_file,
 			   exec_path);
 		printf(">>> Check info.xml and [project//data] folder <%s> <<<\n",
 			   exec_path);
@@ -729,13 +730,9 @@ inline bool sdkCompareBin2BinFloat(const char *src_file, const char *ref_file,
 		printf("  FAILED\n");
 		error_count++;
 
-		if (src_fp) {
-			fclose(src_fp);
-		}
+		if (src_fp) { fclose(src_fp); }
 
-		if (ref_fp) {
-			fclose(ref_fp);
-		}
+		if (ref_fp) { fclose(ref_fp); }
 	} else {
 		if (FOPEN_FAIL(FOPEN(ref_fp, ref_file_path, "rb"))) {
 			printf("compareBin2Bin <float> unable to open ref_file: %s\n",
@@ -744,22 +741,28 @@ inline bool sdkCompareBin2BinFloat(const char *src_file, const char *ref_file,
 		}
 
 		if (src_fp && ref_fp) {
-			src_buffer = reinterpret_cast<float *>(malloc(nelements * sizeof(float)));
-			ref_buffer = reinterpret_cast<float *>(malloc(nelements * sizeof(float)));
+			src_buffer =
+			  reinterpret_cast<float *>(malloc(nelements * sizeof(float)));
+			ref_buffer =
+			  reinterpret_cast<float *>(malloc(nelements * sizeof(float)));
 
 			printf(
-					"> compareBin2Bin <float> nelements=%d, epsilon=%4.2f,"
-					" threshold=%4.2f\n",
-					nelements, epsilon, threshold);
+			  "> compareBin2Bin <float> nelements=%d, epsilon=%4.2f,"
+			  " threshold=%4.2f\n",
+			  nelements,
+			  epsilon,
+			  threshold);
 			fsize = fread(src_buffer, sizeof(float), nelements, src_fp);
-			printf("   src_file <%s>, size=%d bytes\n", src_file,
+			printf("   src_file <%s>, size=%d bytes\n",
+				   src_file,
 				   static_cast<int>(fsize * sizeof(float)));
 			fsize = fread(ref_buffer, sizeof(float), nelements, ref_fp);
-			printf("   ref_file <%s>, size=%d bytes\n", ref_file_path,
+			printf("   ref_file <%s>, size=%d bytes\n",
+				   ref_file_path,
 				   static_cast<int>(fsize * sizeof(float)));
 
 			if (!compareDataAsFloatThreshold<float, float>(
-					ref_buffer, src_buffer, nelements, epsilon, threshold)) {
+				  ref_buffer, src_buffer, nelements, epsilon, threshold)) {
 				error_count++;
 			}
 
@@ -769,23 +772,19 @@ inline bool sdkCompareBin2BinFloat(const char *src_file, const char *ref_file,
 			free(src_buffer);
 			free(ref_buffer);
 		} else {
-			if (src_fp) {
-				fclose(src_fp);
-			}
+			if (src_fp) { fclose(src_fp); }
 
-			if (ref_fp) {
-				fclose(ref_fp);
-			}
+			if (ref_fp) { fclose(ref_fp); }
 		}
 	}
 
 	if (error_count == 0) {
 		printf("  OK\n");
 	} else {
-		printf("  FAILURE: %d errors...\n", (unsigned int) error_count);
+		printf("  FAILURE: %d errors...\n", (unsigned int)error_count);
 	}
 
-	return (error_count == 0);  // returns true if all pixels pass
+	return (error_count == 0); // returns true if all pixels pass
 }
 
 inline bool sdkCompareL2fe(const float *reference, const float *data,
@@ -793,7 +792,7 @@ inline bool sdkCompareL2fe(const float *reference, const float *data,
 	assert(epsilon >= 0);
 
 	float error = 0;
-	float ref = 0;
+	float ref	= 0;
 
 	for (unsigned int i = 0; i < len; ++i) {
 		float diff = reference[i] - data[i];
@@ -811,13 +810,13 @@ inline bool sdkCompareL2fe(const float *reference, const float *data,
 	}
 
 	float normError = sqrtf(error);
-	error = normError / normRef;
-	bool result = error < epsilon;
+	error			= normError / normRef;
+	bool result		= error < epsilon;
 #ifdef _DEBUG
 
 	if (!result) {
-		std::cerr << "ERROR, l2-norm error " << error << " is greater than epsilon "
-				  << epsilon << "\n";
+		std::cerr << "ERROR, l2-norm error " << error
+				  << " is greater than epsilon " << epsilon << "\n";
 	}
 
 #endif
@@ -841,7 +840,7 @@ inline bool sdkLoadPPM4ub(const char *file, unsigned char **data,
 		int size = *w * *h;
 		// keep the original pointer
 		unsigned char *idata_orig = idata;
-		*data = (unsigned char *) malloc(sizeof(unsigned char) * size * 4);
+		*data = (unsigned char *)malloc(sizeof(unsigned char) * size * 4);
 		unsigned char *ptr = *data;
 
 		for (int i = 0; i < size; i++) {
@@ -899,8 +898,8 @@ inline bool sdkComparePPM(const char *src_file, const char *ref_file,
 	if (src_height != ref_height || src_width != ref_width) {
 		if (verboseErrors) {
 			std::cerr << "PPMvsPPM: source and ref size mismatch (" << src_width
-					  << "," << src_height << ")vs(" << ref_width << "," << ref_height
-					  << ")\n";
+					  << "," << src_height << ")vs(" << ref_width << ","
+					  << ref_height << ")\n";
 		}
 	}
 
@@ -910,15 +909,14 @@ inline bool sdkComparePPM(const char *src_file, const char *ref_file,
 				  << threshold * 100 << "%)\n";
 	}
 
-	if (compareData(ref_data, src_data, src_width * src_height * 4, epsilon,
-					threshold) == false) {
+	if (compareData(
+		  ref_data, src_data, src_width * src_height * 4, epsilon, threshold) ==
+		false) {
 		error_count = 1;
 	}
 
 	if (error_count == 0) {
-		if (verboseErrors) {
-			std::cerr << "    OK\n\n";
-		}
+		if (verboseErrors) { std::cerr << "    OK\n\n"; }
 	} else {
 		if (verboseErrors) {
 			std::cerr << "    FAILURE!  " << error_count << " errors...\n\n";
@@ -969,8 +967,8 @@ inline bool sdkComparePGM(const char *src_file, const char *ref_file,
 	if (src_height != ref_height || src_width != ref_width) {
 		if (verboseErrors) {
 			std::cerr << "PGMvsPGM: source and ref size mismatch (" << src_width
-					  << "," << src_height << ")vs(" << ref_width << "," << ref_height
-					  << ")\n";
+					  << "," << src_height << ")vs(" << ref_width << ","
+					  << ref_height << ")\n";
 		}
 	}
 
@@ -979,15 +977,14 @@ inline bool sdkComparePGM(const char *src_file, const char *ref_file,
 				  << src_height << ") epsilon(" << epsilon << "), threshold("
 				  << threshold * 100 << "%)\n";
 
-	if (compareData(ref_data, src_data, src_width * src_height, epsilon,
-					threshold) == false) {
+	if (compareData(
+		  ref_data, src_data, src_width * src_height, epsilon, threshold) ==
+		false) {
 		error_count = 1;
 	}
 
 	if (error_count == 0) {
-		if (verboseErrors) {
-			std::cerr << "    OK\n\n";
-		}
+		if (verboseErrors) { std::cerr << "    OK\n\n"; }
 	} else {
 		if (verboseErrors) {
 			std::cerr << "    FAILURE!  " << error_count << " errors...\n\n";
@@ -998,4 +995,4 @@ inline bool sdkComparePGM(const char *src_file, const char *ref_file,
 	return (error_count == 0) ? true : false;
 }
 
-#endif  // COMMON_HELPER_IMAGE_H_
+#endif // COMMON_HELPER_IMAGE_H_
