@@ -29,30 +29,30 @@
 #define HELPER_MULTIPROCESS_H
 
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
-#ifndef WIN32_LEAN_AND_MEAN
-#define WIN32_LEAN_AND_MEAN
-#endif
+#	ifndef WIN32_LEAN_AND_MEAN
+#		define WIN32_LEAN_AND_MEAN
+#	endif
 
-#include <windows.h>
-#include <iostream>
-#include <stdio.h>
-#include <tchar.h>
-#include <strsafe.h>
-#include <sddl.h>
-#include <aclapi.h>
-#include <winternl.h>
+#	include <aclapi.h>
+#	include <iostream>
+#	include <sddl.h>
+#	include <stdio.h>
+#	include <strsafe.h>
+#	include <tchar.h>
+#	include <windows.h>
+#	include <winternl.h>
 
 #else
-#include <stdio.h>
-#include <fcntl.h>
-#include <sys/mman.h>
-#include <unistd.h>
-#include <errno.h>
-#include <sys/wait.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <memory.h>
-#include <sys/un.h>
+#	include <errno.h>
+#	include <fcntl.h>
+#	include <memory.h>
+#	include <stdio.h>
+#	include <sys/mman.h>
+#	include <sys/socket.h>
+#	include <sys/types.h>
+#	include <sys/un.h>
+#	include <sys/wait.h>
+#	include <unistd.h>
 #endif
 
 #include <vector>
@@ -73,9 +73,10 @@ int sharedMemoryOpen(const char *name, size_t sz, sharedMemoryInfo *info);
 
 void sharedMemoryClose(sharedMemoryInfo *info);
 
-
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
+
 typedef PROCESS_INFORMATION Process;
+
 #else
 typedef pid_t Process;
 #endif
@@ -84,8 +85,11 @@ int spawnProcess(Process *process, const char *app, char *const *args);
 
 int waitProcess(Process *process);
 
-#define checkIpcErrors(ipcFuncResult) \
-    if (ipcFuncResult == -1) { fprintf(stderr, "Failure at %u %s\n", __LINE__, __FILE__); exit(EXIT_FAILURE); }
+#define checkIpcErrors(ipcFuncResult)                                          \
+	if (ipcFuncResult == -1) {                                                 \
+		fprintf(stderr, "Failure at %u %s\n", __LINE__, __FILE__);             \
+		exit(EXIT_FAILURE);                                                    \
+	}
 
 #if defined(__linux__)
 struct ipcHandle_st {
@@ -95,30 +99,30 @@ struct ipcHandle_st {
 typedef int ShareableHandle;
 #elif defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
 struct ipcHandle_st {
-	std::vector<HANDLE> hMailslot; // 1 Handle in case of child and `num children` Handles for parent.
+	std::vector<HANDLE> hMailslot; // 1 Handle in case of child and `num
+								   // children` Handles for parent.
 };
+
 typedef HANDLE ShareableHandle;
+
 #endif
 
 typedef struct ipcHandle_st ipcHandle;
 
-int
-ipcCreateSocket(ipcHandle *&handle, const char *name, const std::vector<Process> &processes);
+int ipcCreateSocket(ipcHandle *&handle, const char *name,
+					const std::vector<Process> &processes);
 
-int
-ipcOpenSocket(ipcHandle *&handle);
+int ipcOpenSocket(ipcHandle *&handle);
 
-int
-ipcCloseSocket(ipcHandle *handle);
+int ipcCloseSocket(ipcHandle *handle);
 
-int
-ipcRecvShareableHandles(ipcHandle *handle, std::vector<ShareableHandle> &shareableHandles);
+int ipcRecvShareableHandles(ipcHandle *handle,
+							std::vector<ShareableHandle> &shareableHandles);
 
-int
-ipcSendShareableHandles(ipcHandle *handle, const std::vector<ShareableHandle> &shareableHandles,
-						const std::vector<Process> &processes);
+int ipcSendShareableHandles(
+  ipcHandle *handle, const std::vector<ShareableHandle> &shareableHandles,
+  const std::vector<Process> &processes);
 
-int
-ipcCloseShareableHandle(ShareableHandle shHandle);
+int ipcCloseShareableHandle(ShareableHandle shHandle);
 
 #endif // HELPER_MULTIPROCESS_H
