@@ -29,80 +29,77 @@
 #ifndef COMMON_HELPER_STRING_H_
 #define COMMON_HELPER_STRING_H_
 
+#include <fstream>
 #include <stdio.h>
 #include <stdlib.h>
-#include <fstream>
 #include <string>
 
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
-#ifndef _CRT_SECURE_NO_DEPRECATE
-#define _CRT_SECURE_NO_DEPRECATE
-#endif
-#ifndef STRCASECMP
-#define STRCASECMP _stricmp
-#endif
-#ifndef STRNCASECMP
-#define STRNCASECMP _strnicmp
-#endif
-#ifndef STRCPY
-#define STRCPY(sFilePath, nLength, sPath) strcpy_s(sFilePath, nLength, sPath)
-#endif
+#	ifndef _CRT_SECURE_NO_DEPRECATE
+#		define _CRT_SECURE_NO_DEPRECATE
+#	endif
+#	ifndef STRCASECMP
+#		define STRCASECMP _stricmp
+#	endif
+#	ifndef STRNCASECMP
+#		define STRNCASECMP _strnicmp
+#	endif
+#	ifndef STRCPY
+#		define STRCPY(sFilePath, nLength, sPath)                              \
+			strcpy_s(sFilePath, nLength, sPath)
+#	endif
 
-#ifndef FOPEN
-#define FOPEN(fHandle, filename, mode) fopen_s(&fHandle, filename, mode)
-#endif
-#ifndef FOPEN_FAIL
-#define FOPEN_FAIL(result) (result != 0)
-#endif
-#ifndef SSCANF
-#define SSCANF sscanf_s
-#endif
-#ifndef SPRINTF
-#define SPRINTF sprintf_s
-#endif
-#else  // Linux Includes
-#include <string.h>
-#include <strings.h>
+#	ifndef FOPEN
+#		define FOPEN(fHandle, filename, mode) fopen_s(&fHandle, filename, mode)
+#	endif
+#	ifndef FOPEN_FAIL
+#		define FOPEN_FAIL(result) (result != 0)
+#	endif
+#	ifndef SSCANF
+#		define SSCANF sscanf_s
+#	endif
+#	ifndef SPRINTF
+#		define SPRINTF sprintf_s
+#	endif
+#else // Linux Includes
+#	include <string.h>
+#	include <strings.h>
 
-#ifndef STRCASECMP
-#define STRCASECMP strcasecmp
-#endif
-#ifndef STRNCASECMP
-#define STRNCASECMP strncasecmp
-#endif
-#ifndef STRCPY
-#define STRCPY(sFilePath, nLength, sPath) strcpy(sFilePath, sPath)
-#endif
+#	ifndef STRCASECMP
+#		define STRCASECMP strcasecmp
+#	endif
+#	ifndef STRNCASECMP
+#		define STRNCASECMP strncasecmp
+#	endif
+#	ifndef STRCPY
+#		define STRCPY(sFilePath, nLength, sPath) strcpy(sFilePath, sPath)
+#	endif
 
-#ifndef FOPEN
-#define FOPEN(fHandle, filename, mode) (fHandle = fopen(filename, mode))
-#endif
-#ifndef FOPEN_FAIL
-#define FOPEN_FAIL(result) (result == NULL)
-#endif
-#ifndef SSCANF
-#define SSCANF sscanf
-#endif
-#ifndef SPRINTF
-#define SPRINTF sprintf
-#endif
+#	ifndef FOPEN
+#		define FOPEN(fHandle, filename, mode) (fHandle = fopen(filename, mode))
+#	endif
+#	ifndef FOPEN_FAIL
+#		define FOPEN_FAIL(result) (result == NULL)
+#	endif
+#	ifndef SSCANF
+#		define SSCANF sscanf
+#	endif
+#	ifndef SPRINTF
+#		define SPRINTF sprintf
+#	endif
 #endif
 
 #ifndef EXIT_WAIVED
-#define EXIT_WAIVED 2
+#	define EXIT_WAIVED 2
 #endif
 
 // CUDA Utility Helper Functions
 inline int stringRemoveDelimiter(char delimiter, const char *string) {
 	int string_start = 0;
 
-	while (string[string_start] == delimiter) {
-		string_start++;
-	}
+	while (string[string_start] == delimiter) { string_start++; }
 
-	if (string_start >= static_cast<int>(strlen(string) - 1)) {
-		return 0;
-	}
+	if (string_start >= static_cast<int>(strlen(string) - 1)) { return 0; }
 
 	return string_start;
 }
@@ -130,12 +127,12 @@ inline bool checkCmdLineFlag(const int argc, const char **argv,
 
 	if (argc >= 1) {
 		for (int i = 1; i < argc; i++) {
-			int string_start = stringRemoveDelimiter('-', argv[i]);
+			int string_start		= stringRemoveDelimiter('-', argv[i]);
 			const char *string_argv = &argv[i][string_start];
 
 			const char *equal_pos = strchr(string_argv, '=');
-			int argv_length = static_cast<int>(
-					equal_pos == 0 ? strlen(string_argv) : equal_pos - string_argv);
+			int argv_length		  = static_cast<int>(
+				equal_pos == 0 ? strlen(string_argv) : equal_pos - string_argv);
 
 			int length = static_cast<int>(strlen(string_ref));
 
@@ -158,18 +155,18 @@ inline bool getCmdLineArgumentValue(const int argc, const char **argv,
 
 	if (argc >= 1) {
 		for (int i = 1; i < argc; i++) {
-			int string_start = stringRemoveDelimiter('-', argv[i]);
+			int string_start		= stringRemoveDelimiter('-', argv[i]);
 			const char *string_argv = &argv[i][string_start];
-			int length = static_cast<int>(strlen(string_ref));
+			int length				= static_cast<int>(strlen(string_ref));
 
 			if (!STRNCASECMP(string_argv, string_ref, length)) {
 				if (length + 1 <= static_cast<int>(strlen(string_argv))) {
 					int auto_inc = (string_argv[length] == '=') ? 1 : 0;
-					*value = (T) atoi(&string_argv[length + auto_inc]);
+					*value		 = (T)atoi(&string_argv[length + auto_inc]);
 				}
 
 				bFound = true;
-				i = argc;
+				i	   = argc;
 			}
 		}
 	}
@@ -180,18 +177,18 @@ inline bool getCmdLineArgumentValue(const int argc, const char **argv,
 inline int getCmdLineArgumentInt(const int argc, const char **argv,
 								 const char *string_ref) {
 	bool bFound = false;
-	int value = -1;
+	int value	= -1;
 
 	if (argc >= 1) {
 		for (int i = 1; i < argc; i++) {
-			int string_start = stringRemoveDelimiter('-', argv[i]);
+			int string_start		= stringRemoveDelimiter('-', argv[i]);
 			const char *string_argv = &argv[i][string_start];
-			int length = static_cast<int>(strlen(string_ref));
+			int length				= static_cast<int>(strlen(string_ref));
 
 			if (!STRNCASECMP(string_argv, string_ref, length)) {
 				if (length + 1 <= static_cast<int>(strlen(string_argv))) {
 					int auto_inc = (string_argv[length] == '=') ? 1 : 0;
-					value = atoi(&string_argv[length + auto_inc]);
+					value		 = atoi(&string_argv[length + auto_inc]);
 				} else {
 					value = 0;
 				}
@@ -216,14 +213,15 @@ inline float getCmdLineArgumentFloat(const int argc, const char **argv,
 
 	if (argc >= 1) {
 		for (int i = 1; i < argc; i++) {
-			int string_start = stringRemoveDelimiter('-', argv[i]);
+			int string_start		= stringRemoveDelimiter('-', argv[i]);
 			const char *string_argv = &argv[i][string_start];
-			int length = static_cast<int>(strlen(string_ref));
+			int length				= static_cast<int>(strlen(string_ref));
 
 			if (!STRNCASECMP(string_argv, string_ref, length)) {
 				if (length + 1 <= static_cast<int>(strlen(string_argv))) {
 					int auto_inc = (string_argv[length] == '=') ? 1 : 0;
-					value = static_cast<float>(atof(&string_argv[length + auto_inc]));
+					value =
+					  static_cast<float>(atof(&string_argv[length + auto_inc]));
 				} else {
 					value = 0.f;
 				}
@@ -248,21 +246,19 @@ inline bool getCmdLineArgumentString(const int argc, const char **argv,
 
 	if (argc >= 1) {
 		for (int i = 1; i < argc; i++) {
-			int string_start = stringRemoveDelimiter('-', argv[i]);
+			int string_start  = stringRemoveDelimiter('-', argv[i]);
 			char *string_argv = const_cast<char *>(&argv[i][string_start]);
-			int length = static_cast<int>(strlen(string_ref));
+			int length		  = static_cast<int>(strlen(string_ref));
 
 			if (!STRNCASECMP(string_argv, string_ref, length)) {
 				*string_retval = &string_argv[length + 1];
-				bFound = true;
+				bFound		   = true;
 				continue;
 			}
 		}
 	}
 
-	if (!bFound) {
-		*string_retval = NULL;
-	}
+	if (!bFound) { *string_retval = NULL; }
 
 	return bFound;
 }
@@ -277,25 +273,25 @@ inline bool getCmdLineArgumentString(const int argc, const char **argv,
 //////////////////////////////////////////////////////////////////////////////
 inline char *sdkFindFilePath(const char *filename,
 							 const char *executable_path) {
-	// <executable_name> defines a variable that is replaced with the name of the
-	// executable
+	// <executable_name> defines a variable that is replaced with the name of
+	// the executable
 
-	// Typical relative search paths to locate needed companion files (e.g. sample
-	// input data, or JIT source files) The origin for the relative search may be
-	// the .exe file, a .bat file launching an .exe, a browser .exe launching the
-	// .exe or .bat, etc
+	// Typical relative search paths to locate needed companion files (e.g.
+	// sample input data, or JIT source files) The origin for the relative
+	// search may be the .exe file, a .bat file launching an .exe, a browser
+	// .exe launching the .exe or .bat, etc
 	const char *searchPath[] = {
-			"./",                                          // same dir
-			"./data/",                                      // same dir
-			"../../../../Samples/<executable_name>/",       // up 4 in tree
-			"../../../Samples/<executable_name>/",          // up 3 in tree
-			"../../Samples/<executable_name>/",             // up 2 in tree
-			"../../../../Samples/<executable_name>/data/",  // up 4 in tree
-			"../../../Samples/<executable_name>/data/",     // up 3 in tree
-			"../../Samples/<executable_name>/data/",        // up 2 in tree
-			"../../../../Common/data/",                     // up 4 in tree
-			"../../../Common/data/",                        // up 3 in tree
-			"../../Common/data/"                            // up 2 in tree
+	  "./",											 // same dir
+	  "./data/",									 // same dir
+	  "../../../../Samples/<executable_name>/",		 // up 4 in tree
+	  "../../../Samples/<executable_name>/",		 // up 3 in tree
+	  "../../Samples/<executable_name>/",			 // up 2 in tree
+	  "../../../../Samples/<executable_name>/data/", // up 4 in tree
+	  "../../../Samples/<executable_name>/data/",	 // up 3 in tree
+	  "../../Samples/<executable_name>/data/",		 // up 2 in tree
+	  "../../../../Common/data/",					 // up 4 in tree
+	  "../../../Common/data/",						 // up 3 in tree
+	  "../../Common/data/"							 // up 2 in tree
 	};
 
 	// Extract the executable name
@@ -330,7 +326,8 @@ inline char *sdkFindFilePath(const char *filename,
 		// replace it with the value
 		if (executable_name_pos != std::string::npos) {
 			if (executable_path != 0) {
-				path.replace(executable_name_pos, strlen("<executable_name>"),
+				path.replace(executable_name_pos,
+							 strlen("<executable_name>"),
 							 executable_name);
 			} else {
 				// Skip this path entry if no executable argument is given
@@ -350,19 +347,19 @@ inline char *sdkFindFilePath(const char *filename,
 		if (fp != NULL) {
 			fclose(fp);
 			// File found
-			// returning an allocated array here for backwards compatibility reasons
-			char *file_path = reinterpret_cast<char *>(malloc(path.length() + 1));
+			// returning an allocated array here for backwards compatibility
+			// reasons
+			char *file_path =
+			  reinterpret_cast<char *>(malloc(path.length() + 1));
 			STRCPY(file_path, path.length() + 1, path.c_str());
 			return file_path;
 		}
 
-		if (fp) {
-			fclose(fp);
-		}
+		if (fp) { fclose(fp); }
 	}
 
 	// File not found
 	return 0;
 }
 
-#endif  // COMMON_HELPER_STRING_H_
+#endif // COMMON_HELPER_STRING_H_
