@@ -30,36 +30,38 @@
 #define COMMON_NVRTC_HELPER_H_ 1
 
 #include <cuda.h>
-#include <helper_cuda_drvapi.h>
-#include <nvrtc.h>
 #include <fstream>
+#include <helper_cuda_drvapi.h>
 #include <iostream>
+#include <nvrtc.h>
 #include <sstream>
 #include <string>
 
-#define NVRTC_SAFE_CALL(Name, x)                                \
-  do {                                                          \
-    nvrtcResult result = x;                                     \
-    if (result != NVRTC_SUCCESS) {                              \
-      std::cerr << "\nerror: " << Name << " failed with error " \
-                << nvrtcGetErrorString(result);                 \
-      exit(1);                                                  \
-    }                                                           \
-  } while (0)
+#define NVRTC_SAFE_CALL(Name, x)                                               \
+	do {                                                                       \
+		nvrtcResult result = x;                                                \
+		if (result != NVRTC_SUCCESS) {                                         \
+			std::cerr << "\nerror: " << Name << " failed with error "          \
+					  << nvrtcGetErrorString(result);                          \
+			exit(1);                                                           \
+		}                                                                      \
+	} while (0)
 
-void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResult,
-						size_t *cubinResultSize, int requiresCGheaders) {
+void compileFileToCUBIN(char *filename, int argc, char **argv,
+						char **cubinResult, size_t *cubinResultSize,
+						int requiresCGheaders) {
 	std::ifstream inputFile(filename,
 							std::ios::in | std::ios::binary | std::ios::ate);
 
 	if (!inputFile.is_open()) {
-		std::cerr << "\nerror: unable to open " << filename << " for reading!\n";
+		std::cerr << "\nerror: unable to open " << filename
+				  << " for reading!\n";
 		exit(1);
 	}
 
 	std::streampos pos = inputFile.tellg();
-	size_t inputSize = (size_t) pos;
-	char *memBlock = new char[inputSize + 1];
+	size_t inputSize   = (size_t)pos;
+	char *memBlock	   = new char[inputSize + 1];
 
 	inputFile.seekg(0, std::ios::beg);
 	inputFile.read(memBlock, inputSize);
@@ -74,13 +76,13 @@ void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResul
 	char deviceName[256];
 
 	// Picks the best CUDA device available
-	CUdevice cuDevice = findCudaDeviceDRV(argc, (const char **) argv);
+	CUdevice cuDevice = findCudaDeviceDRV(argc, (const char **)argv);
 
 	// get compute capabilities and the devicename
 	checkCudaErrors(cuDeviceGetAttribute(
-			&major, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MAJOR, cuDevice));
+	  &major, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MAJOR, cuDevice));
 	checkCudaErrors(cuDeviceGetAttribute(
-			&minor, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MINOR, cuDevice));
+	  &minor, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MINOR, cuDevice));
 
 	{
 		// Compile cubin for the GPU arch on which are going to run cuda kernel.
@@ -88,13 +90,21 @@ void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResul
 		compileOptions = "--gpu-architecture=sm_";
 
 		compileParams[numCompileOptions] = reinterpret_cast<char *>(
-				malloc(sizeof(char) * (compileOptions.length() + 10)));
+		  malloc(sizeof(char) * (compileOptions.length() + 10)));
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
-		sprintf_s(compileParams[numCompileOptions], sizeof(char) * (compileOptions.length() + 10),
-				  "%s%d%d", compileOptions.c_str(), major, minor);
+		sprintf_s(compileParams[numCompileOptions],
+				  sizeof(char) * (compileOptions.length() + 10),
+				  "%s%d%d",
+				  compileOptions.c_str(),
+				  major,
+				  minor);
 #else
-		snprintf(compileParams[numCompileOptions], compileOptions.size() + 10, "%s%d%d",
-				 compileOptions.c_str(), major, minor);
+		snprintf(compileParams[numCompileOptions],
+				 compileOptions.size() + 10,
+				 "%s%d%d",
+				 compileOptions.c_str(),
+				 major,
+				 minor);
 #endif
 	}
 
@@ -104,9 +114,11 @@ void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResul
 		std::string compileOptions;
 		char HeaderNames[256];
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
-		sprintf_s(HeaderNames, sizeof(HeaderNames), "%s", "cooperative_groups.h");
+		sprintf_s(
+		  HeaderNames, sizeof(HeaderNames), "%s", "cooperative_groups.h");
 #else
-		snprintf(HeaderNames, sizeof(HeaderNames), "%s", "cooperative_groups.h");
+		snprintf(
+		  HeaderNames, sizeof(HeaderNames), "%s", "cooperative_groups.h");
 #endif
 
 		compileOptions = "--include-path=";
@@ -117,18 +129,22 @@ void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResul
 			path.erase(found);
 		} else {
 			printf(
-					"\nCooperativeGroups headers not found, please install it in %s "
-					"sample directory..\n Exiting..\n",
-					argv[0]);
+			  "\nCooperativeGroups headers not found, please install it in %s "
+			  "sample directory..\n Exiting..\n",
+			  argv[0]);
 		}
 		compileOptions += path.c_str();
 		compileParams[numCompileOptions] = reinterpret_cast<char *>(
-				malloc(sizeof(char) * (compileOptions.length() + 1)));
+		  malloc(sizeof(char) * (compileOptions.length() + 1)));
 #if defined(WIN32) || defined(_WIN32) || defined(WIN64) || defined(_WIN64)
-		sprintf_s(compileParams[numCompileOptions], sizeof(char) * (compileOptions.length() + 1),
-				  "%s", compileOptions.c_str());
+		sprintf_s(compileParams[numCompileOptions],
+				  sizeof(char) * (compileOptions.length() + 1),
+				  "%s",
+				  compileOptions.c_str());
 #else
-		snprintf(compileParams[numCompileOptions], compileOptions.size(), "%s",
+		snprintf(compileParams[numCompileOptions],
+				 compileOptions.size(),
+				 "%s",
 				 compileOptions.c_str());
 #endif
 		numCompileOptions++;
@@ -136,10 +152,12 @@ void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResul
 
 	// compile
 	nvrtcProgram prog;
-	NVRTC_SAFE_CALL("nvrtcCreateProgram",
-					nvrtcCreateProgram(&prog, memBlock, filename, 0, NULL, NULL));
+	NVRTC_SAFE_CALL(
+	  "nvrtcCreateProgram",
+	  nvrtcCreateProgram(&prog, memBlock, filename, 0, NULL, NULL));
 
-	nvrtcResult res = nvrtcCompileProgram(prog, numCompileOptions, compileParams);
+	nvrtcResult res =
+	  nvrtcCompileProgram(prog, numCompileOptions, compileParams);
 
 	// dump log
 	size_t logSize;
@@ -163,12 +181,10 @@ void compileFileToCUBIN(char *filename, int argc, char **argv, char **cubinResul
 	NVRTC_SAFE_CALL("nvrtcGetCUBINSize", nvrtcGetCUBINSize(prog, &codeSize));
 	char *code = new char[codeSize];
 	NVRTC_SAFE_CALL("nvrtcGetCUBIN", nvrtcGetCUBIN(prog, code));
-	*cubinResult = code;
+	*cubinResult	 = code;
 	*cubinResultSize = codeSize;
 
-	for (int i = 0; i < numCompileOptions; i++) {
-		free(compileParams[i]);
-	}
+	for (int i = 0; i < numCompileOptions; i++) { free(compileParams[i]); }
 }
 
 CUmodule loadCUBIN(char *cubin, int argc, char **argv) {
@@ -178,13 +194,13 @@ CUmodule loadCUBIN(char *cubin, int argc, char **argv) {
 	char deviceName[256];
 
 	// Picks the best CUDA device available
-	CUdevice cuDevice = findCudaDeviceDRV(argc, (const char **) argv);
+	CUdevice cuDevice = findCudaDeviceDRV(argc, (const char **)argv);
 
 	// get compute capabilities and the devicename
 	checkCudaErrors(cuDeviceGetAttribute(
-			&major, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MAJOR, cuDevice));
+	  &major, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MAJOR, cuDevice));
 	checkCudaErrors(cuDeviceGetAttribute(
-			&minor, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MINOR, cuDevice));
+	  &minor, CU_DEVICE_ATTRIBUTE_COMPUTE_CAPABILITY_MINOR, cuDevice));
 	checkCudaErrors(cuDeviceGetName(deviceName, 256, cuDevice));
 	printf("> GPU Device has SM %d.%d compute capability\n", major, minor);
 
@@ -197,4 +213,4 @@ CUmodule loadCUBIN(char *cubin, int argc, char **argv) {
 	return module;
 }
 
-#endif  // COMMON_NVRTC_HELPER_H_
+#endif // COMMON_NVRTC_HELPER_H_
