@@ -48,10 +48,10 @@ PYBIND11_MODULE(_librapid, module) {
 	test.def("sum", [](const std::vector<char> &data) { return testSum(data); });
 
 	module.def("hasBlas", &librapid::hasBlas);
-	// module.def("setBlasThreads", &librapid::setBlasThreads);
-	// module.def("getBlasThreads", &librapid::getBlasThreads);
+	module.def("hasCuda", &librapid::hasCuda);
 	module.def("setNumThreads", &librapid::setNumThreads);
 	module.def("getNumThreads", &librapid::getNumThreads);
+	module.def("optimiseThreads", &librapid::optimiseThreads, py::arg("timePerThread") = 2, py::arg("verbose") = false);
 
 	module.def("seconds", [](){ return librapid::seconds(); });
 	module.def("sleep", &librapid::sleep);
@@ -60,36 +60,92 @@ PYBIND11_MODULE(_librapid, module) {
 
 	module.attr("AUTO") = (int64_t) -1;
 
-	module.attr("pi") = librapid::pi;
-	module.attr("twopi") = librapid::twopi;
-	module.attr("halfpi") = librapid::halfpi;
-	module.attr("e") = librapid::e;
-	module.attr("sqrt2") = librapid::sqrt2;
-	module.attr("sqrt3") = librapid::sqrt3;
-	module.attr("sqrt5") = librapid::sqrt5;
+	module.attr("EPSILON32") = librapid::EPSILON32;
+	module.attr("EPSILON64") = librapid::EPSILON64;
+	module.attr("PISQRDIV6") = librapid::PISQRDIV6;
+	module.attr("RADTODEG") = librapid::RADTODEG;
+	module.attr("DEGTORAD") = librapid::DEGTORAD;
+	module.attr("PI") = librapid::PI;
+	module.attr("SQRTPI") = librapid::SQRTPI;
+	module.attr("TAU") = librapid::TAU;
+	module.attr("HALFPI") = librapid::HALFPI;
+	module.attr("TWOPI") = librapid::TWOPI;
+	module.attr("E") = librapid::E;
+	module.attr("SQRTE") = librapid::SQRTE;
+	module.attr("SQRT2") = librapid::SQRT2;
+	module.attr("SQRT3") = librapid::SQRT3;
+	module.attr("SQRT5") = librapid::SQRT5;
+	module.attr("GOLDENRATIO") = librapid::GOLDENRATIO;
+	module.attr("EULERMASCHERONI") = librapid::EULERMASCHERONI;
+	module.attr("TWINPRIMES") = librapid::TWINPRIMES;
+	module.attr("LN2") = librapid::LN2;
+	module.attr("LN3") = librapid::LN3;
+	module.attr("LN5") = librapid::LN5;
+	module.attr("ZETA3") = librapid::ZETA3;
+	module.attr("CUBEROOT2") = librapid::CUBEROOT2;
+	module.attr("CUBEROOT3") = librapid::CUBEROOT3;
+	module.attr("LIGHTSPEED") = librapid::LIGHTSPEED;
+	module.attr("EARTHGRAVITY") = librapid::EARTHGRAVITY;
+	module.attr("WALLISCONST") = librapid::WALLISCONST;
+	module.attr("LAPLACELIMIT") = librapid::LAPLACELIMIT;
+	module.attr("GAUSSCONST") = librapid::GAUSSCONST;
+	module.attr("CAHENSCONST") = librapid::CAHENSCONST;
+	module.attr("P2") = librapid::P2;
+	module.attr("DOTTIENUMBER") = librapid::DOTTIENUMBER;
+	module.attr("MEISSELMERTENS") = librapid::MEISSELMERTENS;
+	module.attr("ETOPI") = librapid::ETOPI;
+	module.attr("GOLDENANGLE") = librapid::GOLDENANGLE;
+	module.attr("MANDELBROTAREA") = librapid::MANDELBROTAREA;
+	module.attr("GIESEKINGCONST") = librapid::GIESEKINGCONST;
+	module.attr("BLOCHLANDAU") = librapid::BLOCHLANDAU;
+	module.attr("GOLOMBDICKMAN") = librapid::GOLOMBDICKMAN;
+	module.attr("FELLERTORNIER") = librapid::FELLERTORNIER;
+	module.attr("TWOTOSQRT2") = librapid::TWOTOSQRT2;
+	module.attr("KHINCHINSCONST") = librapid::KHINCHINSCONST;
+	module.attr("MILLSCONST") = librapid::MILLSCONST;
+	module.attr("PIOVERLN2") = librapid::PIOVERLN2;
+	module.attr("LOCHSCONST") = librapid::LOCHSCONST;
+	module.attr("NIVENSCONST") = librapid::PIOVERLN2;
+	module.attr("RECIPFIBCONST") = librapid::RECIPFIBCONST;
+	module.attr("BACKHOUSECONST") = librapid::BACKHOUSECONST;
+	module.attr("MRBCONST") = librapid::MRBCONST;
+	module.attr("QUADRECURR") = librapid::QUADRECURR;
+	module.attr("PLASTICNUMBER") = librapid::PLASTICNUMBER;
 
 	module.def("product", [](const std::vector<int64_t> &vals) { return librapid::product(vals); }, py::arg("vals"));
 	module.def("product", [](const std::vector<double> &vals) { return librapid::product(vals); }, py::arg("vals"));
-
+	module.def("anyBelow", [](const std::vector<int64_t> &vals, int64_t bound) { return librapid::anyBelow(vals, bound); }, py::arg("vals"), py::arg("bound") = 0);
 	module.def("min", [](const std::vector<double> &vals) { return librapid::min(vals); }, py::arg("vals"));
 	module.def("max", [](const std::vector<double> &vals) { return librapid::max(vals); }, py::arg("vals"));
-
+	module.def("abs", [](double val) { return librapid::abs(val); }, py::arg("val"));
+	module.def("abs", [](int64_t val) { return librapid::abs(val); }, py::arg("val"));
 	module.def("map", [](double val, double start1, double stop1, double start2, double stop2) { return librapid::map(val, start1, stop1, start2, stop2); }, py::arg("val"), py::arg("start1") = double(0), py::arg("stop1") = double(1), py::arg("start2") = double(0), py::arg("stop2") = double(1));
-	module.def("random", [](int64_t min, int64_t max) { return librapid::random(min, max); }, py::arg("min") = 0, py::arg("max") = 1);
 	module.def("random", [](double min, double max) { return librapid::random(min, max); }, py::arg("min") = 0, py::arg("max") = 1);
 	module.def("randint", [](int64_t min, int64_t max) { return librapid::randint(min, max); }, py::arg("min") = 0, py::arg("max") = 1);
+	module.def("trueRandomEntropy", []() { return librapid::trueRandomEntropy(); });
+	module.def("trueRandom", [](double min, double max) { return librapid::trueRandom(min, max); }, py::arg("min") = 0, py::arg("max") = 1);
+	module.def("trueRandint", [](int64_t min, int64_t max) { return librapid::trueRandint(min, max); }, py::arg("min") = 0, py::arg("max") = 1);
+	module.def("randomGaussian", []() { return librapid::randomGaussian(); });
 	module.def("pow10", &librapid::pow10);
 	module.def("round", [](double val, int64_t places) { return librapid::round(val, places); }, py::arg("val"), py::arg("places") = 0);
 	module.def("roundSigFig", [](double val, int64_t figs) { return librapid::roundSigFig(val, figs); }, py::arg("val"), py::arg("figs") = 3);
 
+	module.def("nthFibonacci", &librapid::nthFibonacci, py::arg("n"));
+	module.def("betterFcknBeEven", &librapid::betterFcknBeEven, py::arg("n"));
+
+	// Create the Vector library
+	#include "./python/vec_interface.hpp"
+
 	// Create the Datatype enum
 	py::enum_<librapid::Datatype>(module, "Datatype")
 	.value("NONE", librapid::Datatype::NONE)
 	.value("VALIDNONE", librapid::Datatype::VALIDNONE)
-	// .value("BOOL", librapid::Datatype::BOOL)
+	.value("INT32", librapid::Datatype::INT32)
 	.value("INT64", librapid::Datatype::INT64)
 	.value("FLOAT32", librapid::Datatype::FLOAT32)
-	.value("FLOAT64", librapid::Datatype::FLOAT64);
+	.value("FLOAT64", librapid::Datatype::FLOAT64)
+	.value("CFLOAT32", librapid::Datatype::CFLOAT32)
+	.value("CFLOAT64", librapid::Datatype::CFLOAT64);
 
 	// Create the Accelerator enum
 	py::enum_<librapid::Accelerator>(module, "Accelerator")
@@ -97,58 +153,71 @@ PYBIND11_MODULE(_librapid, module) {
 	.value("GPU", librapid::Accelerator::GPU);
 
 	module.def("isIntegral", &librapid::isIntegral);
-	module.def("isUnsigned", &librapid::isUnsigned);
 	module.def("isFloating", &librapid::isFloating);
 	module.def("datatypeBytes", &librapid::datatypeBytes);
 	module.def("datatypeToString", &librapid::datatypeToString);
 
+	// Include the vector library
+	#include "python/vec_interface.hpp"
+
 	// The librapid Extent object
 	py::class_<librapid::Extent>(module, "Extent")
-	.def(py::init<>())
-	.def(py::init<const std::vector<int64_t> &>())
-	.def(py::init<const librapid::Extent &>())
-	.def(py::init<py::args>())
+		.def(py::init<>())
+		.def(py::init<const std::vector<int64_t> &>())
+		.def(py::init<const librapid::Extent &>())
+		.def(py::init<py::args>())
 
-	.def("__getitem__", [](const librapid::Extent &e, int64_t index) { return e[index]; })
-	.def("__setitem__", [](librapid::Extent &e, int64_t index, int64_t val) { e[index] = val; })
+		.def("__getitem__", [](const librapid::Extent &e, int64_t index) { return e[index]; })
+		.def("__setitem__", [](librapid::Extent &e, int64_t index, int64_t val) { e[index] = val; })
 
-	.def_property_readonly("ndim", &librapid::Extent::ndim)
-	.def_property_readonly("containsAutomatic", &librapid::Extent::containsAutomatic)
-	.def_property_readonly("size", [](const librapid::Extent &extent) { return static_cast<std::remove_const<librapid::Extent>::type>(extent).size(); })
-	.def("reorder", [](librapid::Extent &e, const std::vector<int64_t> &order) { e.reorder(order); })
-	.def("fixed", &librapid::Extent::fixed)
+		.def_property_readonly("ndim", &librapid::Extent::ndim)
+		.def_property_readonly("containsAutomatic", &librapid::Extent::containsAutomatic)
+		.def_property_readonly("size", [](const librapid::Extent &extent) { return static_cast<std::remove_const<librapid::Extent>::type>(extent).size(); })
+		.def("reorder", [](librapid::Extent &e, const std::vector<int64_t> &order) { e.reorder(order); })
+		.def("fixed", &librapid::Extent::fixed)
 
-	.def("__len__", &librapid::Extent::ndim)
-	.def("__iter__", [](const librapid::Extent &e) { return py::make_iterator(e.begin(), e.end()); }, py::keep_alive<0, 1>())
-	.def("__eq__", &librapid::Extent::operator==)
-	.def("__ne__", &librapid::Extent::operator!=)
-	.def("__str__", &librapid::Extent::str)
-	.def("__repr__", [](const librapid::Extent &e) { return "<librapid." + e.str() + ">"; });
+		.def("__len__", &librapid::Extent::ndim)
+		.def("__iter__", [](const librapid::Extent &e) { return py::make_iterator(e.begin(), e.end()); }, py::keep_alive<0, 1>())
+		.def("__eq__", &librapid::Extent::operator==)
+		.def("__ne__", &librapid::Extent::operator!=)
+		.def("__str__", &librapid::Extent::str)
+		.def("__repr__", [](const librapid::Extent &e) { return "<librapid." + e.str() + ">"; });
 
 	// The librapid Stride object
 	py::class_<librapid::Stride>(module, "Stride")
-	.def(py::init<>())
-	.def(py::init<std::vector<int64_t>>())
-	.def(py::init<int64_t>())
-	.def(py::init<const librapid::Stride &>())
-	.def(py::init<py::args>())
-	.def_static("fromExtent", &librapid::Stride::fromExtent)
+		.def(py::init<>())
+		.def(py::init<std::vector<int64_t>>())
+		.def(py::init<int64_t>())
+		.def(py::init<const librapid::Stride &>())
+		.def(py::init<py::args>())
+		.def_static("fromExtent", &librapid::Stride::fromExtent)
 
-	.def("__getitem__", [](const librapid::Stride &s, int64_t index) { return s[index]; })
-	.def("__setitem__", [](librapid::Stride &s, int64_t index, int64_t val) { s[index] = val; })
+		.def("__getitem__", [](const librapid::Stride &s, int64_t index) { return s[index]; })
+		.def("__setitem__", [](librapid::Stride &s, int64_t index, int64_t val) { s[index] = val; })
 
-	.def_property_readonly("ndim", &librapid::Stride::ndim)
-	.def_property_readonly("isTrivial", &librapid::Stride::isTrivial)
-	.def_property_readonly("isContiguous", &librapid::Stride::isContiguous)
-	.def("reorder", [](librapid::Stride &s, const std::vector<int64_t> &order) { s.reorder(order); })
+		.def_property_readonly("ndim", &librapid::Stride::ndim)
+		.def_property_readonly("isTrivial", &librapid::Stride::isTrivial)
+		.def_property_readonly("isContiguous", &librapid::Stride::isContiguous)
+		.def("reorder", [](librapid::Stride &s, const std::vector<int64_t> &order) { s.reorder(order); })
 
-	.def("__len__", &librapid::Stride::ndim)
+		.def("__len__", &librapid::Stride::ndim)
 
-	.def("__iter__", [](const librapid::Stride &s) { return py::make_iterator(s.begin(), s.end()); }, py::keep_alive<0, 1>())
+		.def("__iter__", [](const librapid::Stride &s) { return py::make_iterator(s.begin(), s.end()); }, py::keep_alive<0, 1>())
 
-	.def("__eq__", &librapid::Stride::operator==)
-	.def("__str__", &librapid::Stride::str)
-	.def("__repr__", [](const librapid::Stride &s) { return "<librapid." + s.str() + ">"; });
+		.def("__eq__", &librapid::Stride::operator==)
+		.def("__str__", &librapid::Stride::str)
+		.def("__repr__", [](const librapid::Stride &s) { return "<librapid." + s.str() + ">"; });
+
+	py::class_<librapid::GPUKernel>(module, "GPUKernel")
+		.def(py::init<>())
+		.def(py::init<const std::string &>(), py::arg("kernel"))
+		.def(py::init<const std::string &, const std::string &>(), py::arg("name"), py::arg("kernel"))
+
+		.def_property_readonly("name", &librapid::GPUKernel::getName)
+		.def_property_readonly("kernel", &librapid::GPUKernel::getKernel)
+
+		.def("__str__", [](const librapid::GPUKernel &e) { return e.str(); })
+		.def("__repr__", [](const librapid::GPUKernel &e) { return "<librapid.GPUKernel \"\n" + e.str() + "\n\">"; });
 
 	// The librapid ndarray object
 	py::class_<librapid::Array>(module, "Array")
@@ -158,17 +227,7 @@ PYBIND11_MODULE(_librapid, module) {
 		.def(py::init<const librapid::Extent &, librapid::Datatype, const std::string &>(), py::arg("extent"), py::arg("dtype") = librapid::Datatype::FLOAT64, py::arg("locn") = "CPU")
 		.def(py::init<const librapid::Extent &, const std::string &, const std::string &>(), py::arg("extent"), py::arg("dtype") = "float64", py::arg("locn") = "CPU")
 		.def(py::init<const librapid::Array &>())
-		// .def(py::init<bool, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<bool>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<bool>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<bool>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<bool>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<bool>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<bool>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<bool>>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<V<bool>>>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::BOOL, py::arg("locn") = librapid::Accelerator::CPU)
+		
 		.def(py::init<int64_t, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::INT64, py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<V<int64_t>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::INT64, py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<V<V<int64_t>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::INT64, py::arg("locn") = librapid::Accelerator::CPU)
@@ -192,17 +251,6 @@ PYBIND11_MODULE(_librapid, module) {
 		.def(py::init<V<V<V<V<V<V<V<V<V<double>>>>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::FLOAT64, py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<V<V<V<V<V<V<V<V<V<V<double>>>>>>>>>>, librapid::Datatype, librapid::Accelerator>(), py::arg("data"), py::arg("dtype") = librapid::Datatype::FLOAT64, py::arg("locn") = librapid::Accelerator::CPU)
 
-		// .def(py::init<bool, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<bool>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<bool>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<bool>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<bool>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<bool>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<bool>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<bool>>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<V<bool>>>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
-		// .def(py::init<V<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<int64_t, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<V<int64_t>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<V<V<int64_t>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
@@ -226,17 +274,6 @@ PYBIND11_MODULE(_librapid, module) {
 		.def(py::init<V<V<V<V<V<V<V<V<V<double>>>>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
 		.def(py::init<V<V<V<V<V<V<V<V<V<V<double>>>>>>>>>>, const std::string &, librapid::Accelerator>(), py::arg("data"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU)
 
-		// .def(py::init<bool, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<bool>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<bool>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<bool>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<bool>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<bool>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<bool>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<bool>>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<V<bool>>>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<int64_t, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<V<int64_t>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<V<V<int64_t>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
@@ -260,17 +297,6 @@ PYBIND11_MODULE(_librapid, module) {
 		.def(py::init<V<V<V<V<V<V<V<V<V<double>>>>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<V<V<V<V<V<V<V<V<V<V<double>>>>>>>>>>, librapid::Datatype, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 
-		// .def(py::init<bool, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<bool>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<bool>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<bool>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<bool>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<bool>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<bool>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<bool>>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<V<bool>>>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
-		// .def(py::init<V<V<V<V<V<V<V<V<V<V<bool>>>>>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<int64_t, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<V<int64_t>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<V<V<int64_t>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
@@ -294,6 +320,13 @@ PYBIND11_MODULE(_librapid, module) {
 		.def(py::init<V<V<V<V<V<V<V<V<V<double>>>>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 		.def(py::init<V<V<V<V<V<V<V<V<V<V<double>>>>>>>>>>, const std::string &, const std::string &>(), py::arg("data"), py::arg("dtype"), py::arg("locn"))
 
+		.def("set", [](librapid::Array &arr, const librapid::Array &other) { arr.set(other); }, py::arg("other"))
+		.def("set", [](librapid::Array &arr, double other) { arr.set(other); }, py::arg("other"))
+		.def("set", [](librapid::Array &arr, int64_t other) { arr.set(other); }, py::arg("other"))
+		.def("set", [](librapid::Array &arr, librapid::Complex<double> other) { arr.set(other); }, py::arg("other"))
+
+		.def("isSame", [](const librapid::Array &arr, const librapid::Array &other) { return arr.isSame(other); }, py::arg("other"))
+
 		.def_property_readonly("ndim", &librapid::Array::ndim)
 		.def_property_readonly("extent", &librapid::Array::extent)
 		.def_property_readonly("stride", &librapid::Array::stride)
@@ -302,10 +335,15 @@ PYBIND11_MODULE(_librapid, module) {
 		.def_property_readonly("location", &librapid::Array::location)
 		.def("__len__", [](const librapid::Array &arr) { return arr.len(); })
 
-		.def("__getitem__", [](const librapid::Array &arr, int64_t index) { return arr[index]; })
-		.def("__setitem__", [](librapid::Array &arr, int64_t index, int64_t val) { arr[index] = val; })
-		.def("__setitem__", [](librapid::Array &arr, int64_t index, double val) { arr[index] = val; })
-		.def("__setitem__", [](librapid::Array &arr, int64_t index, const librapid::Array &val) { arr[index] = val; })
+		.def("__iter__", [](librapid::Array &arr) { arr._increment(); return py::make_iterator(arr.begin(), arr.end()); }) // , py::keep_alive<0, 1>())
+		// .def("__iter__", [](librapid::Array &arr) { /*arr._increment();*/ return py::make_iterator(arr.begin(true), arr.end()); }, py::keep_alive<0, 1>())
+		// .def("__iter__", [](librapid::Array &arr) { return py::make_iterator(arr); })
+
+		.def("subscript", [](const librapid::Array &arr, int64_t index) { return arr.subscript(index); }, py::arg("index"))
+		.def("__getitem__", [](const librapid::Array &arr, int64_t index) { return arr[index]; }, py::arg("index"))
+		.def("__setitem__", [](librapid::Array &arr, int64_t index, int64_t val) { arr[index] = val; }, py::arg("index"), py::arg("val"))
+		.def("__setitem__", [](librapid::Array &arr, int64_t index, double val) { arr[index] = val; }, py::arg("index"), py::arg("val"))
+		.def("__setitem__", [](librapid::Array &arr, int64_t index, const librapid::Array &val) { arr[index] = val; }, py::arg("index"), py::arg("val"))
 
 		.def("fill", [](librapid::Array &arr, int64_t val) { arr.fill(val); })
 		.def("filled", [](librapid::Array &arr, int64_t val) { return arr.filled(val); })
@@ -321,6 +359,16 @@ PYBIND11_MODULE(_librapid, module) {
 		.def("clone", [](const librapid::Array &arr, librapid::Datatype dtype, const std::string &locn) { return arr.clone(dtype, locn); }, py::arg("dtype") = librapid::Datatype::NONE, py::arg("locn") = "none")
 		.def("clone", [](const librapid::Array &arr, const std::string &dtype, const std::string &locn) { return arr.clone(dtype, locn); }, py::arg("dtype") = "none", py::arg("locn") = "none")
 
+		// Include the vector library
+		#include "python/map_kernel_interface.hpp"
+
+		.def("__neg__",     [](const librapid::Array &lhs) { return -lhs; })
+
+		.def("__add__",     [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs + rhs; })
+		.def("__sub__",     [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs - rhs; })
+		.def("__mul__",     [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs * rhs; })
+		.def("__truediv__", [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs / rhs; })
+
 		.def("__add__",     [](const librapid::Array &lhs, int64_t rhs) { return lhs + rhs; })
 		.def("__sub__",     [](const librapid::Array &lhs, int64_t rhs) { return lhs - rhs; })
 		.def("__mul__",     [](const librapid::Array &lhs, int64_t rhs) { return lhs * rhs; })
@@ -341,11 +389,6 @@ PYBIND11_MODULE(_librapid, module) {
 		.def("__rmul__",     [](const librapid::Array &rhs, double lhs) { return lhs * rhs; })
 		.def("__rtruediv__", [](const librapid::Array &rhs, double lhs) { return lhs / rhs; })
 
-		.def("__add__",     [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs + rhs; })
-		.def("__sub__",     [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs - rhs; })
-		.def("__mul__",     [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs * rhs; })
-		.def("__truediv__", [](const librapid::Array &lhs, const librapid::Array &rhs) { return lhs / rhs; })
-
 		.def("reshape", [](librapid::Array &arr, const librapid::Extent &shape) { arr.reshape(shape); })
 		.def("reshape", [](librapid::Array &arr, const std::vector<int64_t> &shape) { arr.reshape(shape); })
 
@@ -373,7 +416,9 @@ PYBIND11_MODULE(_librapid, module) {
 			res += "locn=\"" + locnStr + "\">";
 
 			return res;
-		});
+		})
+
+		.def("refCount", &librapid::Array::refCount);
 
 	module.def("warmup", &librapid::warmup, py::arg("itersCPU") = 10, py::arg("itersGPU") = -1);
 
@@ -382,11 +427,23 @@ PYBIND11_MODULE(_librapid, module) {
 	module.def("randomLike", [](const librapid::Array &arr, int64_t min, int64_t max, int64_t seed) { return librapid::randomLike(arr, min, max, seed); }, py::arg("array"), py::arg("min") = 0, py::arg("max") = 1, py::arg("seed") = -1);
 	module.def("randomLike", [](const librapid::Array &arr, double min, double max, int64_t seed) { return librapid::randomLike(arr, min, max, seed); }, py::arg("array"), py::arg("min") = 0, py::arg("max") = 1, py::arg("seed") = -1);
 
+	module.def("linear", [](double start, double end, int64_t num, const librapid::Datatype &dtype, const librapid::Accelerator &locn) { return librapid::linear(start, end, num, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("num"), py::arg("dtype") = librapid::Datatype::FLOAT64, py::arg("locn") = librapid::Accelerator::CPU);
+	module.def("linear", [](double start, double end, int64_t num, const std::string &dtype, const librapid::Accelerator &locn) { return librapid::linear(start, end, num, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("num"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU);
+	module.def("linear", [](double start, double end, int64_t num, const librapid::Datatype &dtype, const std::string &locn) { return librapid::linear(start, end, num, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("num"), py::arg("dtype"), py::arg("locn") = "CPU");
+	module.def("linear", [](double start, double end, int64_t num, const std::string &dtype, const std::string &locn) { return librapid::linear(start, end, num, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("num"), py::arg("dtype"), py::arg("locn"));
+
+	module.def("range", [](double start, double end, double inc, const librapid::Datatype &dtype, const librapid::Accelerator &locn) { return librapid::range(start, end, inc, dtype, locn); }, py::arg("start") = 0, py::arg("end") = std::numeric_limits<double>::infinity(), py::arg("inc") = 1, py::arg("dtype") = librapid::Datatype::FLOAT64, py::arg("locn") = librapid::Accelerator::CPU);
+	module.def("range", [](double start, double end, double inc, const std::string &dtype, const librapid::Accelerator &locn) { return librapid::range(start, end, inc, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("inc"), py::arg("dtype"), py::arg("locn") = librapid::Accelerator::CPU);
+	module.def("range", [](double start, double end, double inc, const librapid::Datatype &dtype, const std::string &locn) { return librapid::range(start, end, inc, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("inc"), py::arg("dtype"), py::arg("locn") = "CPU");
+	module.def("range", [](double start, double end, double inc, const std::string &dtype, const std::string &locn) { return librapid::range(start, end, inc, dtype, locn); }, py::arg("start"), py::arg("end"), py::arg("inc"), py::arg("dtype"), py::arg("locn"));
+
+	module.def("negate", [](const librapid::Array &a, librapid::Array &res) { librapid::negate(a, res); }, py::arg("a"), py::arg("res"));
 	module.def("add", [](const librapid::Array &a, const librapid::Array &b, librapid::Array &res) { librapid::add(a, b, res); }, py::arg("a"), py::arg("b"), py::arg("res"));
 	module.def("sub", [](const librapid::Array &a, const librapid::Array &b, librapid::Array &res) { librapid::sub(a, b, res); }, py::arg("a"), py::arg("b"), py::arg("res"));
 	module.def("mul", [](const librapid::Array &a, const librapid::Array &b, librapid::Array &res) { librapid::mul(a, b, res); }, py::arg("a"), py::arg("b"), py::arg("res"));
 	module.def("div", [](const librapid::Array &a, const librapid::Array &b, librapid::Array &res) { librapid::div(a, b, res); }, py::arg("a"), py::arg("b"), py::arg("res"));
 
+	module.def("negate", [](const librapid::Array &a) { return librapid::negate(a); }, py::arg("a"));
 	module.def("add", [](const librapid::Array &a, const librapid::Array &b) { return librapid::add(a, b); }, py::arg("a"), py::arg("b"));
 	module.def("sub", [](const librapid::Array &a, const librapid::Array &b) { return librapid::sub(a, b); }, py::arg("a"), py::arg("b"));
 	module.def("mul", [](const librapid::Array &a, const librapid::Array &b) { return librapid::mul(a, b); }, py::arg("a"), py::arg("b"));
